
/* Produces the CPS median income trends by gender used to match the published Census Historical Income Table P-8
   Gets called by robustness.do, and uses the globals specified therein. 
   If running independently of robustness.do, specify paths in the globals commented out below. */

set more off

// global absmob_indir  ""
// global absmob_outdir ""
// global absmob_rawdir   ""

local year_min 1970
local year_max 2014
local clean_cps       true
local compute_medians true

if "`clean_cps'" == "true" {
	
	u "$absmob_rawdir/CPS_1968to2015.dta", clear
	
	keep if age >= 25 & age <= 34
	keep if year >= `year_min' & year <= `year_max'
	
	merge 1:1 year serial pernum using "$absmob_rawdir/cps_swapvalues", nogen
	
	local vlist incalim incaloth incasist incchild incdrt inceduc incgov incidr incint ///
		incother incrent incss incssi incunemp incvet incwelfr incwkcom
	foreach var of varlist `vlist' {
		replace `var' = . if `var' == 99999
	}
	
	local vrbls incdisab incdivid inclongj incretir incsurv oincbus oincfarm ftotval
	foreach var of varlist `vrbls' {
		replace `var' = . if `var' == 999999
	}
	
	local vrs incwage incbus incfarm oincwage
	foreach var of varlist `vrs' {
		replace `var' = . if `var' == 9999999 | `var' == 9999998
	}
	
	replace inctot = . if inctot == 99999999 | inctot == 99999998	
	
	local vars incwage incbus incfarm incss incwelfr incgov incaloth incretir incssi incdrt ///
		incint incunemp incwkcom incvet incsurv incdisab incdivid incrent inceduc incchild incalim ///
		incasist incother inclongj oincbus oincfarm oincwage
	
	foreach var of varlist `vars' {
		replace `var' = `var'_swap if `var'_swap != . & `var'_swap != 0 
	}
	
	// Pre 1988, inctot is the sum of the variables listed in `list87'. Post 1988, inctot is the sum of the variables in `list88'.
	local list75 incwage  incbus  incfarm  incss incidr incaloth incgov incwelfr
	local list87 incwage  incbus  incfarm  incss incretir incssi incint incwelfr incdrt incaloth incgov
	local list88 oincwage oincbus oincfarm incss incretir incssi incint incwelfr inclongj incunemp ///
				 incwkcom incvet incsurv incdisab incdivid incrent inceduc incchild incalim incasist incother
	egen inctotal75 = rowtotal(`list75') if year >= 1968 & year <= 1975
	egen inctotal87 = rowtotal(`list87') if year >= 1976 & year <= 1987
	egen inctotal88 = rowtotal(`list88') if year >= 1988 & year <= 2015
	egen inctot_top = rowtotal(inctotal75 inctotal87 inctotal88)
	
	keep year serial pernum wtsupp bpl age inctot_top sex 
	
	drop if inctot == .
	
	keep year serial pernum sex age wtsupp inctot_top
	sort year serial pernum
	compress
	tempfile CPS_to_match_Census_Table
	save    `CPS_to_match_Census_Table', replace
}

if "`compute_medians'" == "true" {
		
	foreach gender in daughters sons { 
		foreach year of numlist `year_min'/`year_max' {  
					
			use "$absmob_indir/cpirs", clear
							
			sort year
			keep if year == `year' - 1 | year == 2014
			local inflate = rate[1]/rate[2]
	
			use `CPS_to_match_Census_Table', clear
		   
			keep if wtsupp >= 0    	
			keep if year == `year'
			keep if inctot_top != 0
			replace inctot_top = inctot_top/`inflate' 
			
			if "`gender'" == "sons" 	 keep if sex == 1
			if "`gender'" == "daughters" keep if sex == 2
				
			pctile inc_kid        = inctot_top [pw=wtsupp], n(2) genp(percentile)
			
			keep year inc_kid percentile
			
			keep if percentile == 50
			
			tempfile child_distr_`year'
			save    `child_distr_`year'', replace 
			
		}
	
		u `child_distr_`year_min'', clear
		local year_next = `year_min' + 1
		foreach yr of numlist `year_next'/`year_max' {   
			append using `child_distr_`yr''
		}
	
		sort year
		order year 
		compress
		save "$absmob_outdir/CPS_to_match_Census_Table_`gender'", replace
	}
}	
