/* Generates children's income distributions for the decadal cohorts, at age 30, using Census.
   Gets called by robustness.do, and uses the globals specified therein. 
   If running independently of robustness.do, specify paths in the globals commented out below. */

set more off

//global absmob_indir  	""
//global absmob_outdir  ""


//Make the outdir if it doesn't exist
ssc install confirmdir
confirmdir "$absmob_outdir"
if _rc > 0 { 
	mkdir "$absmob_outdir"
}

foreach year of numlist 1970(10)2010 {

	u "$absmob_indir/census`year'_couples.dta", clear 	
	
	//create new (temporary) variables that will allow us to use rowtotal
	tempvar incwelfr incwelfr_spouse
	gen `incwelfr' = -incwelfr
	gen `incwelfr_spouse' = -incwelfr_spouse
		
	egen income = rowtotal(inctot inctot_spouse `incwelfr' `incwelfr_spouse')
	
	drop if income == .

	//keep all 30 year olds. double the row if both spouses are 30 
	keep if age == 30 |  age_spouse == 30
	expand 2 if age == age_spouse

	gen rep_bpl = cond(age == 30, bpl, bpl_spouse)  
	//when doubling a row because both spouses are in the age bracket, change bpl in 1 of them
	bysort id: replace rep_bpl = cond(_n==2, bpl_spouse, bpl)

	//drop immigrants
	keep if rep_bpl < 100 & rep_bpl != . 
	
	//inflate income
	preserve	
	use "$absmob_indir/cpirs", clear
	sort year
	keep year rate
	tempfile inflation
	save    `inflation', replace
	keep if year == 2014
	local inflation_rate = rate[1]
	restore
	
	replace year = year - 1 //income refers to previous calendar year
	merge m:1 year using `inflation', assert(match using) keep(match master) nogen
	replace year = year + 1
	replace rate = rate / `inflation_rate'
	replace income = income/rate
	
	if `year' == 2010 local weights [pw=hhwt] //the 2010 Census requires sampling weights
	if `year' != 2010 local weights
	
	fastxtile percentile = income `weights', n(100)
	collapse (mean) kid_inc = income, by(percentile)
	keep percentile kid_inc
	
	merge 1:1 percentile using "$absmob_indir/zero_incomes", nogen
	sort percentile
	//For all missing values, if _n = 2 or 1, set value to 0 else, set value to _N-1
	replace kid_inc = cond(mi(kid_inc), cond(_n<=2, 0, kid_inc[_n-1]), kid_inc)		
	replace kid_inc = round(kid_inc)			
	
	local cohort = `year' - 30
	gen cohort = `cohort'
	
	tempfile kid_`cohort'
	save    `kid_`cohort'', replace 
		
}
	
	use `kid_1940', clear
	forval i = 1950(10)1980 {
		append using `kid_`i''
	}
	order cohort percentile
	save "$absmob_outdir/kid_marginal", replace					



